/*
 * Copyright (C) {2006}, International Business Machines Corporation and others. All Rights Reserved.
 */
 
/*code for testing timezone data updates 2006a and above*/

#include <unicode/timezone.h>
#include <unicode/calendar.h>
#include <stdio.h>

#ifndef NULL
#define NULL 0L
#endif

#define MYASSERT(x) if(!(x)) {printf("%s:%d: assert failed %s\n", __FILE__, __LINE__, #x);fail=TRUE;}
#define MYASSERT_ABORT(x) if(!(x)) {printf("%s:%d: assert failed %s\n", __FILE__, __LINE__, #x);return 1;}
#define AN_HOUR 3600000
#define PST_BASE (AN_HOUR*8)
#define IND_BASE (AN_HOUR*5)
int main(void)
{
    UBool fail = FALSE;
    const TimeZone* gmt = TimeZone::getGMT();
    TimeZone *pst = TimeZone::createTimeZone(UnicodeString("America/Los_Angeles"));
    TimeZone *ai = TimeZone::createTimeZone(UnicodeString("America/Indianapolis"));
    TimeZone *aii = TimeZone::createTimeZone(UnicodeString("America/Indiana/Indianapolis"));
    
    printf("Checking for general sanity..\n");
    MYASSERT_ABORT(pst!=NULL);
    MYASSERT_ABORT(ai!=NULL);
    MYASSERT(aii!=NULL);
   // MYASSERT((*ai)==(*aii)); // IDs dont match

    MYASSERT(pst->useDaylightTime()==TRUE);
    MYASSERT(gmt->useDaylightTime()==FALSE);
    
    UErrorCode status = U_ZERO_ERROR;
    Calendar *cal = Calendar::createInstance(gmt->clone(),status);
    MYASSERT_ABORT(U_SUCCESS(status));

    cal->set(2006,UCAL_APRIL,2,1,59,59);
    UDate justBeforeDst06 = cal->getTime(status);
    cal->set(2006,UCAL_APRIL,2,2,00,00);
    UDate justAfterDst06 = cal->getTime(status);

    cal->set(2007,UCAL_MARCH,11,1,59,59);
    UDate justBeforeDst07 = cal->getTime(status);
    cal->set(2007,UCAL_MARCH,11,2,00,00);
    UDate justAfterDst07 = cal->getTime(status);

    MYASSERT_ABORT(U_SUCCESS(status));
    
    printf("Checking Indiana (2006) DST changes...\n");
    MYASSERT(ai->inDaylightTime(justBeforeDst06+IND_BASE,status)==FALSE);
    MYASSERT(ai->inDaylightTime(justAfterDst06+IND_BASE,status)==TRUE);
    MYASSERT(ai->inDaylightTime(justBeforeDst07+IND_BASE,status)==FALSE);
    MYASSERT(ai->inDaylightTime(justAfterDst07+IND_BASE,status)==TRUE);
    MYASSERT(ai->useDaylightTime()==TRUE);
    MYASSERT(aii->useDaylightTime()==TRUE);
    MYASSERT(ai->getRawOffset()==aii->getRawOffset());

    printf("Checking US (2007) DST changes...\n");
    MYASSERT(pst->inDaylightTime(justBeforeDst06+PST_BASE,status)==FALSE);
    MYASSERT(pst->inDaylightTime(justAfterDst06+PST_BASE,status)==TRUE);
    MYASSERT(pst->inDaylightTime(justBeforeDst07+PST_BASE,status)==FALSE);
    MYASSERT(pst->inDaylightTime(justAfterDst07+PST_BASE,status)==TRUE);
    
    delete pst;
    delete ai;
    delete aii;
    
    if(fail) {
        printf("FAILURE.\n");
        return 1;
    } else {
        printf("All OK.\n");
        return 0;
    }
}